@@ -1,8 +1,7 @@
 const APP = {
   config: {
     env: process.env.APP_ENV,
-    apiUrl: process.env.APP_API,
-    platformUrl: process.env.PLATFORM_URL
+    apiUrl: process.env.APP_API
   }
 }
 
